::: {{cookiecutter.project_slug}}

## Configuration

::: {{cookiecutter.project_slug}}.config

## Constants

::: {{cookiecutter.project_slug}}.constants

## Components

::: {{cookiecutter.project_slug}}.components

## Logger

::: {{cookiecutter.project_slug}}.logger

## Utils

::: {{cookiecutter.project_slug}}.utils

## Exceptions

::: {{cookiecutter.project_slug}}.exception

## Entities

::: {{cookiecutter.project_slug}}.entity

## Pipeline

::: {{cookiecutter.project_slug}}.pipeline

## Routes

::: {{cookiecutter.project_slug}}.routes
